@@ -30,16 +30,20 @@ int     iconic = 0;
 int     pushed_in = 1;
 char    display_name[50];
 char    mainGeometry[50];
+char	window_name[50];
 
 void defaults()
 {
 	state.update_interval = CHK_INTERVAL;
 	state.draw_seconds = 1;
 	state.draw_date = 1;
+	state.draw_ampm = 1;
+	state.shift = 0;
 	withdrawn = 0;
 	iconic = 0; 
 	pushed_in = 1;
 	state.total_size.x = state.total_size.y = 54;
+	safecopy(window_name, "astime", 50);
 	safecopy(display_name, "", 50);
 	safecopy(mainGeometry, "", 50);
 	safecopy(state.bgcolor, "#385971", 50);
@@ -60,11 +64,14 @@ void usage()
         printf("-u <secs>       the update interval in seconds\n");
         printf("-nosec		don't draw the second pointer\n");
         printf("-nodate		don't show the date/day of the week\n");
+        printf("-noampm		don't show the AM/PM indicator\n");
         printf("-display <name> the name of the display to use\n");
         printf("-geometry <xywh> position/size on the screen (X geometry)\n");
         printf("-withdrawn      start in withdrawn shape (for WindowMaker)\n");
         printf("-iconic         start iconized\n");
         printf("-standout       standing out rather than being pushed in\n");
+	printf("-shift <hrs>	show the time with the given shift in hours\n");
+	printf("-title <name>	set the window/icon title to this name\n");
 	printf("-bg <color>	background color\n");
 	printf("-fg <color>	dial foreground color\n");
 	printf("-sec <color>	second pointer color\n");
@@ -79,7 +86,7 @@ void usage()
 /* print the version of the tool */
 void version()
 {
-        printf("astime : AfterStep analogue clock version 1.4\n");
+        printf("astime : AfterStep analogue clock version 1.5\n");
 }               
 
 void    parsecmdline(int argc, char *argv[])
@@ -103,14 +110,26 @@ void    parsecmdline(int argc, char *argv[])
                                 state.update_interval = atoi(argv[i]);
                                 if ( state.update_interval < 1 )  
                                         state.update_interval = CHK_INTERVAL;
+                        } else if (!strncmp(argument,"-shift",6)) {
+                                if (++i >= argc)
+                                        usage();
+                                state.shift = atoi(argv[i]);
+				if ( (state.shift > 23) || (state.shift < -23) )
+					state.shift = 0;
                         } else if (!strncmp(argument,"-nosec",6)) {
                                 state.draw_seconds=0;
                         } else if (!strncmp(argument,"-nodate",7)) {
                                 state.draw_date=0;
+                        } else if (!strncmp(argument,"-noampm",7)) {
+                                state.draw_ampm=0;
                         } else if (!strncmp(argument,"-geometry",9)) {
                                 if (++i >= argc)
                                         usage();
                                 safecopy(mainGeometry, argv[i], 50);
+                        } else if (!strncmp(argument,"-title",6)) {
+                                if (++i >= argc)
+                                        usage();
+                                safecopy(window_name, argv[i], 50);
                         } else if (!strncmp(argument,"-display",8)) {
                                 if (++i >= argc)
                                         usage();
@@ -169,6 +188,7 @@ void main(int argc, char** argv)
 	defaults();
 	parsecmdline(argc, argv);
 	initialize(argc, argv, 
+			window_name,
 			display_name, 
 			mainGeometry, 
 			withdrawn, 
