@@ -22,6 +22,7 @@ struct astime_state state;
 #include "dof.xpm"
 #include "months.xpm"
 #include "digits.xpm"
+#include "ampm.xpm"
 
 /* nice idea from ascd */
 typedef struct _XpmIcon {
@@ -31,6 +32,7 @@ typedef struct _XpmIcon {
 } XpmIcon;
 
 XpmIcon dofXpm;
+XpmIcon ampmXpm;
 XpmIcon monthsXpm;
 XpmIcon digitsXpm;
 
@@ -49,6 +51,7 @@ Atom wm_protocols;
 /* background, digits, months etc pixmap colors */
 char bgpixmap_color[4][50];
 char dof_pixmap_color[2][50];
+char ampm_pixmap_color[2][50];
 char digits_pixmap_color[2][50];
 char months_pixmap_color[2][50];
 
@@ -98,6 +101,19 @@ void draw_window(Window win)
                 0,
                 0
                 );
+	if ( state.draw_ampm )
+		XCopyArea(
+			mainDisplay,
+			ampmXpm.pixmap,
+			win,
+			mainGC,
+			0,
+			(loc_time->tm_hour > 12 ? 6 : 0),
+			13,
+			7,
+			state.total_size.x - 14,
+			1
+			);
 	if ( state.draw_date ) {
 		XCopyArea(
 			mainDisplay,
@@ -258,6 +274,13 @@ void calculate_pointers()
 {
 	float xrate, yrate;
 	loc_time = localtime(&curTime);
+	if (state.shift) {
+		loc_time->tm_hour += state.shift;
+		while (loc_time->tm_hour > 23)
+			loc_time->tm_hour %= 24;
+		while (loc_time->tm_hour < 0)
+			loc_time->tm_hour += 24;
+	}
 	/* seconds */
 	xrate = convert2x(loc_time->tm_sec);
 	yrate = convert2y(loc_time->tm_sec);
@@ -511,6 +534,7 @@ void draw_dial()
 
 void initialize(
 			int argc, char** argv,
+			char * window_name,
 			char * display_name,
 			char * mainGeometry,
                         int withdrawn,
@@ -522,7 +546,6 @@ void initialize(
 	XWindowAttributes winAttr;
 	XSizeHints SizeHints;
 	XTextProperty title;
-	char * app_name = "astime";
 	XClassHint classHint;
 	int gravity;
 	XWMHints WmHints;
@@ -605,6 +628,25 @@ void initialize(
                 printf("astime : (%d) not enough free color cells for day_of_week.\n", status);   
 		x_cleanup();
         }       
+	/* The AM/PM pixmap */
+	sprintf(ampm_pixmap_color[0], "c c %s", state.bgcolor);
+	sprintf(ampm_pixmap_color[1], "l c %s", state.daycolor);
+	ampm[1] = ampm_pixmap_color[0];
+	ampm[2] = ampm_pixmap_color[1];
+	ampmXpm.attributes.valuemask |=
+                (XpmReturnPixels | XpmReturnExtensions);
+        status = XpmCreatePixmapFromData(
+                mainDisplay,                    /* display */
+                Root,                           /* window */
+                ampm,                     /* xpm */ 
+                &ampmXpm.pixmap,          /* resulting pixmap */
+                &ampmXpm.mask,
+                &ampmXpm.attributes
+                );
+        if(status != XpmSuccess) {
+                printf("astime : (%d) not enough free color cells for AM/PM indicator.\n", status);   
+		x_cleanup();
+        }       
 	/* The digits pixmap */
 	sprintf(digits_pixmap_color[0], "c c %s", state.bgcolor);
 	sprintf(digits_pixmap_color[1], ". c %s", state.datecolor);
@@ -745,15 +787,15 @@ void initialize(
 		winAttr.border_width);
 #endif
                 
-        status = XStringListToTextProperty(&app_name, 1, &title);
+        status = XStringListToTextProperty(&window_name, 1, &title);
         XSetWMName(mainDisplay, mainWindow, &title);
         XSetWMName(mainDisplay, iconWindow, &title);
         
         classHint.res_name = "astime" ;
         classHint.res_class = "ASTIME";
         XSetClassHint(mainDisplay, mainWindow, &classHint);
-        XStoreName(mainDisplay, mainWindow, "astime");
-        XSetIconName(mainDisplay, mainWindow, "astime");
+        XStoreName(mainDisplay, mainWindow, window_name);
+        XSetIconName(mainDisplay, mainWindow, window_name);
 
         status = XSelectInput(
                 mainDisplay,    /* display */
