@@ -10,7 +10,9 @@ struct astime_state {
 	long int update_interval; /* interval (sec) to update the dial */
 	unsigned short int draw_seconds;
 	unsigned short int draw_date;
+	unsigned short int draw_ampm;
 	struct coordinates total_size;
+	short int shift;
 	char bgcolor[50];
 	char fgcolor[50];
 	char seccolor[50];
